@@ -1,6 +1,8 @@
 package App::CharmKit::Command::lint;
 
-# ABSTRACT: Charm Linter
+=head1 NAME
+
+App::CharmKit::Command::lint - charm linter
 
 =head1 SYNOPSIS
 
